package org.apache.commons.lang3.function;

import java.lang.Throwable;
import java.util.Objects;

/* loaded from: org_apache_commons_lang3_function.jar:org/apache/commons/lang3/function/FailableDoubleUnaryOperator.class */
public interface FailableDoubleUnaryOperator<E extends Throwable> {
    public static final FailableDoubleUnaryOperator NOP = t -> {
        return 0.0d;
    };

    double applyAsDouble(double d) throws Throwable;

    static <E extends Throwable> FailableDoubleUnaryOperator<E> identity() {
        return t -> {
            return t;
        };
    }

    static <E extends Throwable> FailableDoubleUnaryOperator<E> nop() {
        return NOP;
    }

    default FailableDoubleUnaryOperator<E> andThen(FailableDoubleUnaryOperator<E> after) {
        Objects.requireNonNull(after);
        return t -> {
            return after.applyAsDouble(applyAsDouble(t));
        };
    }

    default FailableDoubleUnaryOperator<E> compose(FailableDoubleUnaryOperator<E> before) {
        Objects.requireNonNull(before);
        return v -> {
            return applyAsDouble(before.applyAsDouble(v));
        };
    }
}
